// SPDX-License-Identifier: LGPL-2.1-or-later
//
// SPDX-FileCopyrightText: 2013 Mohammed Nafees <nafees.technocool@gmail.com>

#include "GpsbabelPlugin.h"

#include <klocalizedstring.h>

#include "GpsbabelRunner.h"

namespace Marble
{

GpsbabelPlugin::GpsbabelPlugin(QObject* const parent)
    : ParseRunnerPlugin(parent)
{
}

QString GpsbabelPlugin::name() const
{
    return i18n( "GPSBabel NMEA File Parser" );
}

QString GpsbabelPlugin::nameId() const
{
    return QStringLiteral("GPSBabel");
}

QString GpsbabelPlugin::version() const
{
    return QStringLiteral("1.0");
}

QString GpsbabelPlugin::description() const
{
    return i18n( "A plugin to load Geolocation Data from NMEA files through GPSBabel command line tool." );
}

QString GpsbabelPlugin::copyrightYears() const
{
    return QStringLiteral("2013");
}

QVector<PluginAuthor> GpsbabelPlugin::pluginAuthors() const
{
    return QVector<PluginAuthor>()
            << PluginAuthor(QStringLiteral("Mohammed Nafees"), QStringLiteral("nafees.technocool@gmail.com"));
}

QString GpsbabelPlugin::fileFormatDescription() const
{
    return i18n( "GPSBabel files" );
}

QStringList GpsbabelPlugin::fileExtensions() const
{
    return QStringList()
        << QStringLiteral("nmea")
        << QStringLiteral("igc")
        << QStringLiteral("tiger")
        << QStringLiteral("ov2")
        << QStringLiteral("garmin")
        << QStringLiteral("csv")
        << QStringLiteral("magellan");
}

ParsingRunner* GpsbabelPlugin::newRunner() const
{
    return new GpsbabelRunner;
}

} // namespace Marble

#include "moc_GpsbabelPlugin.cpp"
